==> kjy-center-api-0.10.45-test-1.0.1-20201117.032702-1-sources.jar: cn/com/duiba/kjy/api/dto/RocketMqTag.java <==
package cn.com.duiba.kjy.api.dto;


/**
 * Created by dugq on 2019-03-27.
 */
public abstract class RocketMqTag {

    /**
     * 贺卡红包，企业付款到领取回调
     */
    public static final String GREETING_COMPANY_PAY_CALLBACK= "GREETING_COMPANY_PAY_CALLBACK";

    /**
     * 提现，企业付款到领取回调
     */
    public static final String WITHDRAW_COMPANY_PAY_CALLBACK= "WITHDRAW_COMPANY_PAY_CALLBACK";

    /**
     * 晚安问候推送消息
     */
    public static final String TAG_PUSH_EVENING_GREETING = "push_evening_greeting";

    /**
     * 客集集VIP公众号微信通知消息
     */
    public static final String TAG_KJJ_VIP_OA_WX_NOTIFY = "TAG_KJJ_VIP_OA_WX_NOTIFY";

    /**
     * 客集集批量推送消息
     */
    public static final String TAG_KJJ_BATCH_NOTIFY = "TAG_KJJ_BATCH_NOTIFY";

    /**
     * 钉钉通知消息
     */
    public static final String TAG_KJJ_DING_TALK = "tag_kjj_ding_talk";

    private static final String KJY_CONTENT_PUSH_INFORMATION = "KjyContentPushInformation";
    private static final String KJY_CONTENT_GRAB_INFORMATION = "KjyContentGrabInformation";
    private static final String KJY_GRAB_SOURCE_RELOAD_INFORMATION = "KjyGrabSourceReloadInformation";
    private static final String KJY_USER_AVATAR_RETRY_INFORMATION = "kjyUserAvatarRetryInformation";

    private static final String KJY_ACTIVITY_SUBMIT_MESSAGE = "KJY_ACTIVITY_SUBMIT_MESSAGE";

    private static final String KJY_VIP_UNSUBSCRIBE_MESSAGE = "KJY_VIP_UNSUBSCRIBE_MESSAGE";


    /**
     * 客集集销售员导入任务
     */
    public static final String KJY_SELLER_IMPORT_MESSAGE = "KjySellerImportMessage";

    /**
     * 私信相关的消息，包含客户进入聊天，客户留言，代理人留言
     */
    public static final String KJY_PRIVATE_CHAT_SEND_MESSAGE = "KJY_PRIVATE_CHAT_SEND_MESSAGE";

    /**
     * 今日运势消息推送
     */
    public static final String TODAY_LUCK_PUSH_TAG = "TODAY_LUCK_PUSH_TAG";

    /**
     * 访问线索延迟分析
     */
    public static final String VISIT_CLUE_DELAY_ANALYSE_PUSH = "VISIT_CLUE_DELAY_ANALYSE_PUSH";

    /**
     * 代理人推送数据同步
     */
    public static final String SELLER_PUSH_DATA_SYNC = "SELLER_PUSH_DATA_SYNC";

    public static String getSellerPushDataSync() {
        return SELLER_PUSH_DATA_SYNC;
    }

    public static String getDailySignTag() {
        return DAILY_SIGN_TAG;
    }

    /**
     * 今日日签
     */
    public static final String DAILY_SIGN_TAG = "DAILY_SIGN_TAG";

    /**
     * 群发消息推送tag
     */
    public static final String MASS_MESSAGE_PUSH_TAG = "MASS_MESSAGE_PUSH_TAG";


    /**
     * 上传完成消息推送
     */
    public static final String IMPORT_TASK_PUSH_MSG = "IMPORT_TASK_PUSH_MSG";

    /**
     * 视频类型转换消息  mp4 -> ts
     */
    public static final String VIDEO_TYPE_CONVERT_MSG = "VIDEO_TYPE_CONVERT_MSG";


    public static String getKjyFaqSendPushMsg() {
        return KJY_FAQ_SEND_PUSH_MSG;
    }

    /**
     * faq线索延迟消息topic
     */
    public static final String KJY_FAQ_SEND_PUSH_MSG = "KJY_FAQ_SEND_PUSH_MSG";


    /**
     * faq线索延迟检测消息
     */
    public static final String KJY_FAQ_SEND_DELAY_MSG = "KJY_FAQ_SEND_DELAY_MSG";

    /**
     * 中台-抓取用户微信头像消息
     */
    public static final String TAG_KJJ_USER_AVATAR_IMG = "TAG_KJJ_USER_AVATAR_IMG";
    /**
     * 每日素材推送tag
     */
    public static final String DAILY_CONTENT_PUSH_TAG = "DAILY_CONTENT_PUSH_TAG";

    /**
     * 风险评测延迟检测消息
     */
    public static final String KJY_SEND_DELAY_RISK_TEST_MSG = "KJY_SEND_DELAY_RISK_TEST_MSG";

    /**
     * 素材的es同步
     */
    public static final String CONTENT_ES_SYNC = "CONTENT_ES_SYNC";

    public static String getKjySendDelayRiskTestMsg() {
        return KJY_SEND_DELAY_RISK_TEST_MSG;
    }

    public static String getKjyFaqSendDelayMsg() {
        return KJY_FAQ_SEND_DELAY_MSG;
    }

    public static String getVideoTypeConvertMsg() {
        return VIDEO_TYPE_CONVERT_MSG;
    }

    public static String getKjyContentPushInformation() {
        return KJY_CONTENT_PUSH_INFORMATION;
    }

    public static String getKjyContentGrabInformation() {
        return KJY_CONTENT_GRAB_INFORMATION;
    }

    public static String getKjyGrabSourceReloadInformation() {
        return KJY_GRAB_SOURCE_RELOAD_INFORMATION;
    }

    public static String getKjyActivitySubmitMessage() {
        return KJY_ACTIVITY_SUBMIT_MESSAGE;
    }

    public static String getKjyVipUnsubscribeMessage() {
        return KJY_VIP_UNSUBSCRIBE_MESSAGE;
    }

    public static String getVisitClueDelayAnalysePush() {
        return VISIT_CLUE_DELAY_ANALYSE_PUSH;
    }

    public static String getKjyUserAvatarRetryInformation() {
        return KJY_USER_AVATAR_RETRY_INFORMATION;
    }


}

==> kjy-center-api-0.11.86-test-4-20210805.030045-2-sources.jar: cn/com/duiba/kjy/api/dto/RocketMqTag.java <==
package cn.com.duiba.kjy.api.dto;


/**
 * Created by dugq on 2019-03-27.
 */
public abstract class RocketMqTag {

    /**
     * 贺卡红包，企业付款到领取回调
     */
    public static final String GREETING_COMPANY_PAY_CALLBACK= "GREETING_COMPANY_PAY_CALLBACK";

    /**
     * 提现，企业付款到领取回调
     */
    public static final String WITHDRAW_COMPANY_PAY_CALLBACK= "WITHDRAW_COMPANY_PAY_CALLBACK";

    /**
     * 晚安问候推送消息
     */
    public static final String TAG_PUSH_EVENING_GREETING = "push_evening_greeting";

    /**
     * 客集集VIP公众号微信通知消息
     */
    public static final String TAG_KJJ_VIP_OA_WX_NOTIFY = "TAG_KJJ_VIP_OA_WX_NOTIFY";

    /**
     * 客集集批量推送消息
     */
    public static final String TAG_KJJ_BATCH_NOTIFY = "TAG_KJJ_BATCH_NOTIFY";

    /**
     * 钉钉通知消息
     */
    public static final String TAG_KJJ_DING_TALK = "tag_kjj_ding_talk";

    private static final String KJY_CONTENT_PUSH_INFORMATION = "KjyContentPushInformation";
    private static final String KJY_CONTENT_GRAB_INFORMATION = "KjyContentGrabInformation";
    private static final String KJY_GRAB_SOURCE_RELOAD_INFORMATION = "KjyGrabSourceReloadInformation";
    private static final String KJY_USER_AVATAR_RETRY_INFORMATION = "kjyUserAvatarRetryInformation";

    private static final String KJY_ACTIVITY_SUBMIT_MESSAGE = "KJY_ACTIVITY_SUBMIT_MESSAGE";

    private static final String KJY_VIP_UNSUBSCRIBE_MESSAGE = "KJY_VIP_UNSUBSCRIBE_MESSAGE";


    /**
     * 客集集销售员导入任务
     */
    public static final String KJY_SELLER_IMPORT_MESSAGE = "KjySellerImportMessage";

    /**
     * 私信相关的消息，包含客户进入聊天，客户留言，代理人留言
     */
    public static final String KJY_PRIVATE_CHAT_SEND_MESSAGE = "KJY_PRIVATE_CHAT_SEND_MESSAGE";

    /**
     * 今日运势消息推送
     */
    public static final String TODAY_LUCK_PUSH_TAG = "TODAY_LUCK_PUSH_TAG";

    /**
     * 访问线索延迟分析
     */
    public static final String VISIT_CLUE_DELAY_ANALYSE_PUSH = "VISIT_CLUE_DELAY_ANALYSE_PUSH";

    /**
     * 代理人推送数据同步
     */
    public static final String SELLER_PUSH_DATA_SYNC = "SELLER_PUSH_DATA_SYNC";

    public static String getSellerPushDataSync() {
        return SELLER_PUSH_DATA_SYNC;
    }

    public static String getDailySignTag() {
        return DAILY_SIGN_TAG;
    }

    /**
     * 今日日签
     */
    public static final String DAILY_SIGN_TAG = "DAILY_SIGN_TAG";

    /**
     * 群发消息推送tag
     */
    public static final String MASS_MESSAGE_PUSH_TAG = "MASS_MESSAGE_PUSH_TAG";


    /**
     * 上传完成消息推送
     */
    public static final String IMPORT_TASK_PUSH_MSG = "IMPORT_TASK_PUSH_MSG";

    /**
     * 视频类型转换消息  mp4 -> ts
     */
    public static final String VIDEO_TYPE_CONVERT_MSG = "VIDEO_TYPE_CONVERT_MSG";


    public static String getKjyFaqSendPushMsg() {
        return KJY_FAQ_SEND_PUSH_MSG;
    }

    /**
     * faq线索延迟消息topic
     */
    public static final String KJY_FAQ_SEND_PUSH_MSG = "KJY_FAQ_SEND_PUSH_MSG";


    /**
     * faq线索延迟检测消息
     */
    public static final String KJY_FAQ_SEND_DELAY_MSG = "KJY_FAQ_SEND_DELAY_MSG";

    /**
     * 中台-抓取用户微信头像消息
     */
    public static final String TAG_KJJ_USER_AVATAR_IMG = "TAG_KJJ_USER_AVATAR_IMG";
    /**
     * 每日素材推送tag
     */
    public static final String DAILY_CONTENT_PUSH_TAG = "DAILY_CONTENT_PUSH_TAG";

    /**
     * 风险评测延迟检测消息
     */
    public static final String KJY_SEND_DELAY_RISK_TEST_MSG = "KJY_SEND_DELAY_RISK_TEST_MSG";

    /**
     * 素材的es同步
     */
    public static final String CONTENT_ES_SYNC = "CONTENT_ES_SYNC";

    /**
     * 微信公众号爬取tag
     */
    public static final String KJJ_WECHAT_OA_GRAB_TAG = "KJJ_WECHAT_OA_GRAB_TAG";
    /**
     * 文章链接爬取tag
     */
    public static final String KJJ_GRAB_CONTENT_TAG = "KJJ_GRAB_CONTENT_TAG";
    /**
     * 抖音视频爬取tag
     */
    public static final String KJJ_GRAB_VIDEO_TAG = "KJJ_GRAB_VIDEO_TAG";
    /**
     * 微信公众号cookie tag
     */
    public static final String KJJ_WECHAT_OA_COOKIE_TAG = "KJJ_WECHAT_OA_COOKIE_TAG";

    /**
     * 微博爬虫tag
     */
    public static final String KJJ_WB_GRAB_CONTENT_TAG = "KJJ_WB_GRAB_CONTENT_TAG";

    /**
     * ai跟拍助手ffmpeg合成视频相框参数tag(kjy-web => kjy-manager)
     */
    public static final String AI_VIDEO_COMPOSE_CALL_BACK_TAG = "KJJ_AI_VIDEO_COMPOSE_TAG";

    /**
     * ai跟拍助手ffmpeg合成视频相框结果tag(kjy-manager => kjy-web)
     */
    public static final String AI_VIDEO_COMPOSE_RESULT_CALL_BACK_TAG = "KJJ_AI_VIDEO_COMPOSE_RESULT_TAG";


    public static String getKjySendDelayRiskTestMsg() {
        return KJY_SEND_DELAY_RISK_TEST_MSG;
    }

    public static String getKjyFaqSendDelayMsg() {
        return KJY_FAQ_SEND_DELAY_MSG;
    }

    public static String getVideoTypeConvertMsg() {
        return VIDEO_TYPE_CONVERT_MSG;
    }

    public static String getKjyContentPushInformation() {
        return KJY_CONTENT_PUSH_INFORMATION;
    }

    public static String getKjyContentGrabInformation() {
        return KJY_CONTENT_GRAB_INFORMATION;
    }

    public static String getKjyGrabSourceReloadInformation() {
        return KJY_GRAB_SOURCE_RELOAD_INFORMATION;
    }

    public static String getKjyActivitySubmitMessage() {
        return KJY_ACTIVITY_SUBMIT_MESSAGE;
    }

    public static String getKjyVipUnsubscribeMessage() {
        return KJY_VIP_UNSUBSCRIBE_MESSAGE;
    }

    public static String getVisitClueDelayAnalysePush() {
        return VISIT_CLUE_DELAY_ANALYSE_PUSH;
    }

    public static String getKjyUserAvatarRetryInformation() {
        return KJY_USER_AVATAR_RETRY_INFORMATION;
    }

    public static String getAiVideoComposeCallBackTag() {
        return AI_VIDEO_COMPOSE_CALL_BACK_TAG;
    }

    public static String getAiVideoComposeResultCallBackTag() {
        return AI_VIDEO_COMPOSE_RESULT_CALL_BACK_TAG;
    }
}
